@@ -21,44 +21,51 @@ class Organization(ApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Organization): return False
+        if not isinstance(other, Organization):
+            return False
         return self.gitea == other.gitea and self.name == other.name
 
     def __hash__(self):
         return hash(self.gitea) ^ hash(self.name)
 
     @classmethod
-    def request(cls, gitea: 'Gitea', name: str) -> 'Organization':
+    def request(cls, gitea: "Gitea", name: str) -> "Organization":
         return cls._request(gitea, {"name": name})
 
     @classmethod
-    def parse_response(cls, gitea, result) -> 'Organization':
+    def parse_response(cls, gitea, result) -> "Organization":
         api_object = super().parse_response(gitea, result)
-        # add "name" field to make this behave similar to users
-        Organization._add_read_property("name", result["username"], api_object)
+        # add "name" field to make this behave similar to users for gitea < 1.18
+        # also necessary for repository-owner when org is repo owner
+        if not hasattr(api_object, "name"):
+            Organization._add_read_property("name", result["username"], api_object)
         return api_object
 
-    _patchable_fields = {"description", "full_name", "location", "visibility", "website"}
+    _patchable_fields = {
+        "description",
+        "full_name",
+        "location",
+        "visibility",
+        "website",
+    }
 
     def commit(self):
         values = self.get_dirty_fields()
         args = {"name": self.name}
-        self.gitea.requests_patch(
-            Organization.API_OBJECT.format(**args), data=values
-        )
+        self.gitea.requests_patch(Organization.API_OBJECT.format(**args), data=values)
         self.dirty_fields = {}
 
     def create_repo(
-            self,
-            repoName: str,
-            description: str = "",
-            private: bool = False,
-            autoInit=True,
-            gitignores: str = None,
-            license: str = None,
-            readme: str = "Default",
-            issue_labels: str = None,
-            default_branch="master",
+        self,
+        repoName: str,
+        description: str = "",
+        private: bool = False,
+        autoInit=True,
+        gitignores: str = None,
+        license: str = None,
+        readme: str = "Default",
+        issue_labels: str = None,
+        default_branch="master",
     ):
         """Create an organization Repository
 
@@ -81,7 +88,9 @@ class Organization(ApiObject):
             },
         )
         if "id" in result:
-            self.gitea.logger.info("Successfully created Repository %s " % result["name"])
+            self.gitea.logger.info(
+                "Successfully created Repository %s " % result["name"]
+            )
         else:
             self.gitea.logger.error(result["message"])
             raise Exception("Repository not created... (gitea: %s)" % result["message"])
@@ -106,7 +115,8 @@ class Organization(ApiObject):
         )
         teams = [Team.parse_response(self.gitea, result) for result in results]
         # organisation seems to be missing using this request, so we add org manually
-        for t in teams: setattr(t, "_organization", self)
+        for t in teams:
+            setattr(t, "_organization", self)
         return teams
 
     def get_team(self, name) -> "Team":
@@ -137,7 +147,7 @@ class Organization(ApiObject):
         self.gitea.requests_delete(path)
 
     def delete(self):
-        """ Delete this Organization. Invalidates this Objects data. Also deletes all Repositories owned by the User"""
+        """Delete this Organization. Invalidates this Objects data. Also deletes all Repositories owned by the User"""
         for repo in self.get_repositories():
             repo.delete()
         self.gitea.requests_delete(Organization.API_OBJECT.format(name=self.username))
@@ -165,7 +175,8 @@ class User(ApiObject):
         self._emails = []
 
     def __eq__(self, other):
-        if not isinstance(other, User): return False
+        if not isinstance(other, User):
+            return False
         return self.gitea == other.gitea and self.id == other.id
 
     def __hash__(self):
@@ -177,7 +188,7 @@ class User(ApiObject):
         return self._emails
 
     @classmethod
-    def request(cls, gitea: 'Gitea', name: str) -> "User":
+    def request(cls, gitea: "Gitea", name: str) -> "User":
         api_object = cls._request(gitea, {"name": name})
         return api_object
 
@@ -215,16 +226,16 @@ class User(ApiObject):
         self.dirty_fields = {}
 
     def create_repo(
-            self,
-            repoName: str,
-            description: str = "",
-            private: bool = False,
-            autoInit=True,
-            gitignores: str = None,
-            license: str = None,
-            readme: str = "Default",
-            issue_labels: str = None,
-            default_branch="master",
+        self,
+        repoName: str,
+        description: str = "",
+        private: bool = False,
+        autoInit=True,
+        gitignores: str = None,
+        license: str = None,
+        readme: str = "Default",
+        issue_labels: str = None,
+        default_branch="master",
     ):
         """Create a user Repository
 
@@ -247,31 +258,33 @@ class User(ApiObject):
             },
         )
         if "id" in result:
-            self.gitea.logger.info("Successfully created Repository %s " % result["name"])
+            self.gitea.logger.info(
+                "Successfully created Repository %s " % result["name"]
+            )
         else:
             self.gitea.logger.error(result["message"])
             raise Exception("Repository not created... (gitea: %s)" % result["message"])
         return Repository.parse_response(self, result)
 
     def get_repositories(self) -> List["Repository"]:
-        """ Get all Repositories owned by this User."""
+        """Get all Repositories owned by this User."""
         url = f"/users/{self.username}/repos"
-        results = self.gitea.requests_get(url)
+        results = self.gitea.requests_get_paginated(url)
         return [Repository.parse_response(self.gitea, result) for result in results]
 
     def get_orgs(self) -> List[Organization]:
-        """ Get all Organizations this user is a member of."""
+        """Get all Organizations this user is a member of."""
         url = f"/users/{self.username}/orgs"
-        results = self.gitea.requests_get(url)
+        results = self.gitea.requests_get_paginated(url)
         return [Organization.parse_response(self.gitea, result) for result in results]
 
-    def get_teams(self) -> List['Team']:
+    def get_teams(self) -> List["Team"]:
         url = f"/user/teams"
         results = self.gitea.requests_get_paginated(url, sudo=self)
         return [Team.parse_response(self.gitea, result) for result in results]
 
-    def get_accessible_repos(self) -> List['Repository']:
-        """ Get all Repositories accessible by the logged in User."""
+    def get_accessible_repos(self) -> List["Repository"]:
+        """Get all Repositories accessible by the logged in User."""
         results = self.gitea.requests_get("/user/repos", sudo=self)
         return [Repository.parse_response(self, result) for result in results]
 
@@ -284,7 +297,7 @@ class User(ApiObject):
                 self._email = mail["email"]
 
     def delete(self):
-        """ Deletes this User. Also deletes all Repositories he owns."""
+        """Deletes this User. Also deletes all Repositories he owns."""
         self.gitea.requests_delete(User.ADMIN_DELETE_USER % self.username)
         self.deleted = True
 
@@ -298,7 +311,6 @@ class User(ApiObject):
 
 
 class Branch(ReadonlyApiObject):
-
     def __init__(self, gitea):
         super().__init__(gitea)
 
@@ -316,13 +328,16 @@ class Branch(ReadonlyApiObject):
     }
 
     @classmethod
-    def request(cls, gitea: 'Gitea', owner: str, repo: str, ref: str):
+    def request(cls, gitea: "Gitea", owner: str, repo: str, ref: str):
         return cls._request(gitea, {"owner": owner, "repo": repo, "ref": ref})
 
 
 class Repository(ApiObject):
     API_OBJECT = """/repos/{owner}/{name}"""  # <owner>, <reponame>
-    REPO_IS_COLLABORATOR = """/repos/%s/%s/collaborators/%s"""  # <owner>, <reponame>, <username>
+    REPO_MIGRATE = """/repos/migrate"""
+    REPO_IS_COLLABORATOR = (
+        """/repos/%s/%s/collaborators/%s"""  # <owner>, <reponame>, <username>
+    )
     REPO_SEARCH = """/repos/search/%s"""  # <reponame>
     REPO_BRANCHES = """/repos/%s/%s/branches"""  # <owner>, <reponame>
     REPO_ISSUES = """/repos/{owner}/{repo}/issues"""  # <owner, reponame>
@@ -337,7 +352,8 @@ class Repository(ApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Repository): return False
+        if not isinstance(other, Repository):
+            return False
         return self.owner == other.owner and self.name == other.name
 
     def __hash__(self):
@@ -346,32 +362,51 @@ class Repository(ApiObject):
     _fields_to_parsers = {
         # dont know how to tell apart user and org as owner except form email being empty.
         "owner": lambda gitea, r: Organization.parse_response(gitea, r)
-        if r["email"] == "" else User.parse_response(gitea, r),
+        if r["email"] == ""
+        else User.parse_response(gitea, r),
         "updated_at": lambda gitea, t: Util.convert_time(t),
     }
 
     @classmethod
-    def request(cls, gitea: 'Gitea', owner: str, name: str):
+    def request(cls, gitea: "Gitea", owner: str, name: str):
         return cls._request(gitea, {"owner": owner, "name": name})
 
     _patchable_fields = {
+        "allow_manual_merge",
         "allow_merge_commits",
         "allow_rebase",
         "allow_rebase_explicit",
+        "allow_rebase_update",
         "allow_squash_merge",
         "archived",
+        "autodetect_manual_merge",
         "default_branch",
+        "default_delete_branch_after_merge",
+        "default_merge_style",
         "description",
+        "enable_prune",
+        "external_tracker",
+        "external_wiki",
         "has_issues",
+        "has_projects",
         "has_pull_requests",
         "has_wiki",
         "ignore_whitespace_conflicts",
+        "internal_tracker",
+        "mirror_interval",
         "name",
         "private",
+        "template",
         "website",
     }
 
-    def get_branches(self) -> List['Branch']:
+    def commit(self):
+        values = self.get_dirty_fields()
+        args = {"owner": self.owner.username, "name": self.name}
+        self.gitea.requests_patch(self.API_OBJECT.format(**args), data=values)
+        self.dirty_fields = {}
+
+    def get_branches(self) -> List["Branch"]:
         """Get all the Branches of this Repository."""
         results = self.gitea.requests_get(
             Repository.REPO_BRANCHES % (self.owner.username, self.name)
@@ -391,11 +426,12 @@ class Repository(ApiObject):
         """Get all Issues of this Repository (open and closed)"""
         return self.get_issues_state(Issue.OPENED) + self.get_issues_state(Issue.CLOSED)
 
-    def get_commits(self) -> List["Commit"]:
+    def get_commits(self, page_limit: int = 0) -> List["Commit"]:
         """Get all the Commits of this Repository."""
         try:
             results = self.gitea.requests_get_paginated(
-                Repository.REPO_COMMITS % (self.owner.username, self.name)
+                Repository.REPO_COMMITS % (self.owner.username, self.name),
+                page_limit= page_limit
             )
         except ConflictException as err:
             logging.warning(err)
@@ -411,7 +447,8 @@ class Repository(ApiObject):
         issues = []
         data = {"state": state}
         results = self.gitea.requests_get_paginated(
-            Repository.REPO_ISSUES.format(owner=self.owner.username, repo=self.name), params=data
+            Repository.REPO_ISSUES.format(owner=self.owner.username, repo=self.name),
+            params=data,
         )
         for result in results:
             issue = Issue.parse_response(self.gitea, result)
@@ -447,14 +484,20 @@ class Repository(ApiObject):
             "title": title,
         }
         result = self.gitea.requests_post(
-            Repository.REPO_ISSUES.format(owner=self.owner.username, repo=self.name), data=data
+            Repository.REPO_ISSUES.format(owner=self.owner.username, repo=self.name),
+            data=data,
         )
         return Issue.parse_response(self.gitea, result)
 
-    def create_milestone(self, title: str, description: str, due_date: str = None, state: str = "open") -> "Milestone":
-        url = Repository.REPO_MILESTONES.format(owner=self.owner.username, repo=self.name)
+    def create_milestone(
+        self, title: str, description: str, due_date: str = None, state: str = "open"
+    ) -> "Milestone":
+        url = Repository.REPO_MILESTONES.format(
+            owner=self.owner.username, repo=self.name
+        )
         data = {"title": title, "description": description, "state": state}
-        if due_date: data["due_date"] = due_date
+        if due_date:
+            data["due_date"] = due_date
         result = self.gitea.requests_post(url, data=data)
         return Milestone.parse_response(self.gitea, result)
 
@@ -508,30 +551,62 @@ class Repository(ApiObject):
         url = f"/repos/{self.owner.username}/{self.name}/collaborators/{user_name}"
         self.gitea.requests_delete(url)
 
-    def transfer_ownership(self, new_owner: Union["User", "Organization"], new_teams: Set["Team"] = frozenset()):
+    def transfer_ownership(
+        self,
+        new_owner: Union["User", "Organization"],
+        new_teams: Set["Team"] = frozenset(),
+    ):
         url = Repository.REPO_TRANSFER.format(owner=self.owner.username, repo=self.name)
         data = {"new_owner": new_owner.username}
         if isinstance(new_owner, Organization):
-            new_team_ids = [team.id for team in new_teams if team in new_owner.get_teams()]
+            new_team_ids = [
+                team.id for team in new_teams if team in new_owner.get_teams()
+            ]
             data["team_ids"] = new_team_ids
         self.gitea.requests_post(url, data=data)
         # TODO: make sure this instance is either updated or discarded
 
-    def get_git_content(self: str = None, commit: "Commit" = None) -> List["Content"]:
-        """https://git.sopranium.de/api/swagger#/repository/repoGetContentsList"""
+    def get_git_content(self, commit: "Commit" = None) -> List["Content"]:
+        """https://try.gitea.io/api/swagger#/repository/repoGetContentsList"""
         url = f"/repos/{self.owner.username}/{self.name}/contents"
         data = {"ref": commit.sha} if commit else {}
-        result = [Content.parse_response(self.gitea, f) for f in self.gitea.requests_get(url, data)]
+        result = [
+            Content.parse_response(self.gitea, f)
+            for f in self.gitea.requests_get(url, data)
+        ]
         return result
 
-    def get_file_content(self, content: "Content", commit: "Commit" = None) -> Union[str, List["Content"]]:
-        """https://git.sopranium.de/api/swagger#/repository/repoGetContents"""
+    def get_file_content(
+        self, content: "Content", commit: "Commit" = None
+    ) -> Union[str, List["Content"]]:
+        """https://try.gitea.io/api/swagger#/repository/repoGetContents"""
         url = f"/repos/{self.owner.username}/{self.name}/contents/{content.path}"
         data = {"ref": commit.sha} if commit else {}
         if content.type == Content.FILE:
             return self.gitea.requests_get(url, data)["content"]
         else:
-            return [Content.parse_response(self.gitea, f) for f in self.gitea.requests_get(url, data)]
+            return [
+                Content.parse_response(self.gitea, f)
+                for f in self.gitea.requests_get(url, data)
+            ]
+
+    def create_file(self, file_path: str, content: str, data: dict = None):
+        """https://try.gitea.io/api/swagger#/repository/repoCreateFile"""
+        if not data:
+            data = {}
+        url = f"/repos/{self.owner.username}/{self.name}/contents/{file_path}"
+        data.update({"content": content})
+        return self.gitea.requests_post(url, data)
+
+    def change_file(
+        self, file_path: str, file_sha: str, content: str, data: dict = None
+    ):
+        """https://try.gitea.io/api/swagger#/repository/repoCreateFile"""
+        if not data:
+            data = {}
+        url = f"/repos/{self.owner.username}/{self.name}/contents/{file_path}"
+        data.update({"sha": file_sha, "content": content})
+        return self.gitea.requests_put(url, data)
 
     def delete(self):
         self.gitea.requests_delete(
@@ -539,6 +614,71 @@ class Repository(ApiObject):
         )
         self.deleted = True
 
+    @classmethod
+    def migrate_repo(
+        cls,
+        gitea: "Gitea",
+        service: str,
+        clone_addr: str,
+        repo_name: str,
+        description: str = "",
+        private: bool = False,
+        auth_token: str = None,
+        auth_username: str = None,
+        auth_password: str = None,
+        mirror: bool = False,
+        mirror_interval: str = None,
+        lfs: bool = False,
+        lfs_endpoint: str = "",
+        wiki: bool = False,
+        labels: bool = False,
+        issues: bool = False,
+        pull_requests: bool = False,
+        releases: bool = False,
+        milestones: bool = False,
+        repo_owner: str = None,
+    ):
+        """Migrate a Repository from another service.
+
+        Throws:
+            AlreadyExistsException: If the Repository exists already.
+            Exception: If something else went wrong.
+        """
+        result = gitea.requests_post(
+            cls.REPO_MIGRATE,
+            data={
+                "auth_password": auth_password,
+                "auth_token": auth_token,
+                "auth_username": auth_username,
+                "clone_addr": clone_addr,
+                "description": description,
+                "issues": issues,
+                "labels": labels,
+                "lfs": lfs,
+                "lfs_endpoint": lfs_endpoint,
+                "milestones": milestones,
+                "mirror": mirror,
+                "mirror_interval": mirror_interval,
+                "private": private,
+                "pull_requests": pull_requests,
+                "releases": releases,
+                "repo_name": repo_name,
+                "repo_owner": repo_owner,
+                "service": service,
+                "wiki": wiki,
+            },
+        )
+        if "id" in result:
+            gitea.logger.info(
+                "Successfully created Job to Migrate Repository %s " % result["name"]
+            )
+        else:
+            gitea.logger.error(result["message"])
+            raise Exception(
+                "Repository not Migrated... (gitea: %s)" % result["message"]
+            )
+        return Repository.parse_response(gitea, result)
+
 
 class Milestone(ApiObject):
     API_OBJECT = """/repos/{owner}/{repo}/milestones/{number}"""  # <owner, repo>
@@ -547,7 +687,8 @@ class Milestone(ApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Milestone): return False
+        if not isinstance(other, Milestone):
+            return False
         return self.gitea == other.gitea and self.id == other.id
 
     def __hash__(self):
@@ -576,17 +717,17 @@ class Milestone(ApiObject):
     }
 
     @classmethod
-    def request(cls, gitea: 'Gitea', owner: str, repo: str, number: str):
+    def request(cls, gitea: "Gitea", owner: str, repo: str, number: str):
         return cls._request(gitea, {"owner": owner, "repo": repo, "number": number})
 
 
 class Comment(ApiObject):
-
     def __init__(self, gitea):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Comment): return False
+        if not isinstance(other, Comment):
+            return False
         return self.repo == other.repo and self.id == other.id
 
     def __hash__(self):
@@ -600,24 +741,26 @@ class Comment(ApiObject):
 
 
 class Commit(ReadonlyApiObject):
-
     def __init__(self, gitea):
         super().__init__(gitea)
 
     _fields_to_parsers = {
         # NOTE: api may return None for commiters that are no gitea users
-        "author": lambda gitea, u: User.parse_response(gitea, u) if u else None
+        "author": lambda gitea, u: User.parse_response(gitea, u)
+        if u
+        else None
     }
 
     def __eq__(self, other):
-        if not isinstance(other, Commit): return False
+        if not isinstance(other, Commit):
+            return False
         return self.sha == other.sha
 
     def __hash__(self):
         return hash(self.sha)
 
     @classmethod
-    def parse_response(cls, gitea, result) -> 'Commit':
+    def parse_response(cls, gitea, result) -> "Commit":
         commit_cache = result["commit"]
         api_object = cls(gitea)
         cls._initialize(gitea, api_object, result)
@@ -639,7 +782,8 @@ class Issue(ApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Issue): return False
+        if not isinstance(other, Issue):
+            return False
         return self.repo == other.repo and self.id == other.id
 
     def __hash__(self):
@@ -652,7 +796,7 @@ class Issue(ApiObject):
         "assignees": lambda gitea, us: [User.parse_response(gitea, u) for u in us],
         "state": lambda gitea, s: Issue.CLOSED if s == "closed" else Issue.OPENED,
         # Repository in this request is just a "RepositoryMeta" record, thus request whole object
-        "repository": lambda gitea, r: Repository.request(gitea, r["owner"], r["name"])
+        "repository": lambda gitea, r: Repository.request(gitea, r["owner"], r["name"]),
     }
 
     _parsers_to_fields = {
@@ -671,13 +815,19 @@ class Issue(ApiObject):
 
     def commit(self):
         values = self.get_dirty_fields()
-        args = {"owner": self.repository.owner.username, "repo": self.repository.name, "index": self.number}
+        args = {
+            "owner": self.repository.owner.username,
+            "repo": self.repository.name,
+            "index": self.number,
+        }
         self.gitea.requests_patch(Issue.API_OBJECT.format(**args), data=values)
         self.dirty_fields = {}
 
     @classmethod
-    def request(cls, gitea: 'Gitea', owner: str, repo: str, number: str):
-        api_object = cls._request(gitea, {"owner": owner, "repo": repo, "index": number})
+    def request(cls, gitea: "Gitea", owner: str, repo: str, number: str):
+        api_object = cls._request(
+            gitea, {"owner": owner, "repo": repo, "index": number}
+        )
         return api_object
 
     @classmethod
@@ -729,7 +879,6 @@ class Issue(ApiObject):
 
 class Team(ApiObject):
     API_OBJECT = """/teams/{id}"""  # <id>
-    ADD_USER = """/teams/%s/members/%s"""  # <id, username to add>
     ADD_REPO = """/teams/%s/repos/%s/%s"""  # <id, org, repo>
     TEAM_DELETE = """/teams/%s"""  # <id>
     GET_MEMBERS = """/teams/%s/members"""  # <id>
@@ -739,7 +888,8 @@ class Team(ApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Team): return False
+        if not isinstance(other, Team):
+            return False
         return self.organization == other.organization and self.id == other.id
 
     def __hash__(self):
@@ -749,25 +899,41 @@ class Team(ApiObject):
         "organization": lambda gitea, o: Organization.parse_response(gitea, o)
     }
 
+    _patchable_fields = {
+        "can_create_org_repo",
+        "description",
+        "includes_all_repositories",
+        "name",
+        "permission",
+        "units",
+        "units_map",
+    }
+
     @classmethod
-    def request(cls, gitea: 'Gitea', organization: str, team: str):
+    def request(cls, gitea: "Gitea", id: int):
         return cls._request(gitea, {"id": id})
 
-    _patchable_fields = {"description", "name", "permission", "units"}
+    def commit(self):
+        values = self.get_dirty_fields()
+        args = {"id": self.id}
+        self.gitea.requests_patch(self.API_OBJECT.format(**args), data=values)
+        self.dirty_fields = {}
 
     def add_user(self, user: User):
-        self.gitea.requests_put(Team.ADD_USER % (self.id, user.login))
+        """https://try.gitea.io/api/swagger#/organization/orgAddTeamMember"""
+        url = f"/teams/{self.id}/members/{user.login}"
+        self.gitea.requests_put(url)
 
     def add_repo(self, org: Organization, repo: Repository):
         self.gitea.requests_put(Team.ADD_REPO % (self.id, org, repo.name))
 
     def get_members(self):
-        """ Get all users assigned to the team. """
+        """Get all users assigned to the team."""
         results = self.gitea.requests_get(Team.GET_MEMBERS % self.id)
         return [User.parse_response(self.gitea, result) for result in results]
 
     def get_repos(self):
-        """ Get all repos of this Team."""
+        """Get all repos of this Team."""
         results = self.gitea.requests_get(Team.GET_REPOS % self.id)
         return [Repository.parse_response(self.gitea, result) for result in results]
 
@@ -787,8 +953,11 @@ class Content(ReadonlyApiObject):
         super().__init__(gitea)
 
     def __eq__(self, other):
-        if not isinstance(other, Team): return False
-        return self.repo == self.repo and self.sha == other.sha and self.name == other.name
+        if not isinstance(other, Team):
+            return False
+        return (
+            self.repo == self.repo and self.sha == other.sha and self.name == other.name
+        )
 
     def __hash__(self):
         return hash(self.repo) ^ hash(self.sha) ^ hash(self.name)
@@ -797,8 +966,19 @@ class Content(ReadonlyApiObject):
 class Util:
     @staticmethod
     def convert_time(time: str) -> datetime:
-        """ Parsing of strange Gitea time format ("%Y-%m-%dT%H:%M:%S:%z" but with ":" in time zone notation)"""
+        """Parsing of strange Gitea time format ("%Y-%m-%dT%H:%M:%S:%z" but with ":" in time zone notation)"""
         try:
             return datetime.strptime(time[:-3] + "00", "%Y-%m-%dT%H:%M:%S%z")
         except ValueError:
             return datetime.strptime(time[:-3] + "00", "%Y-%m-%dT%H:%M:%S")
+
+
+class MigrationServices:
+    GIT = "1"
+    GITHUB = "2"
+    GITEA = "3"
+    GITLAB = "4"
+    GOGS = "5"
+    ONEDEV = "6"
+    GITBUCKET = "7"
+    CODEBASE = "8"
